@@ -521,13 +521,13 @@ def model_api_test(m, dynamic_shapes: {str: tuple} = None):
                 'macsdiff': macsdiffacc}
 
 
-def model_shape_regress(m, min_shape: {}, max_shape: {}):
+def model_shape_regress(m, input_desc: {}, input_range: {}):
     if isinstance(m, str):
         m = onnx.load_model(m)
     if isinstance(m, onnx.ModelProto):
         G = Graph(m.graph)
         G.graph_reorder()
-        G.shape_regress(min_shape, max_shape)
+        G.shape_regress(input_desc, input_range)
 
 
 def model_remove_Identity(m, f: str):
